==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/icon/folder.ico.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "folder.ico"

unsigned char _mgir_ico_folder_data[]={
	0x00,0x00,0x01,0x00,0x02,0x00,0x10,0x10,	0x10,0x00,0x00,0x00,0x00,0x00,0x28,0x01,
	0x00,0x00,0x26,0x00,0x00,0x00,0x20,0x20,	0x10,0x00,0x00,0x00,0x00,0x00,0xE8,0x02,
	0x00,0x00,0x4E,0x01,0x00,0x00,0x28,0x00,	0x00,0x00,0x10,0x00,0x00,0x00,0x20,0x00,
	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,	0x00,0x00,0xC0,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,
	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,
	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,
	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x88,
	0x88,0x88,0x88,0x88,0x88,0x00,0x8F,0xB7,	0xB0,0x00,0x07,0xB7,0xB8,0x00,0x8F,0x7B,
	0x70,0xF7,0x0B,0x7B,0x78,0x00,0x8F,0xB0,	0x00,0x7F,0x00,0x00,0xB8,0x00,0x8F,0x70,
	0x74,0x44,0x0F,0x70,0x78,0x00,0x8F,0xB0,	0xB7,0xB7,0x47,0xF0,0xB8,0x08,0x8F,0x70,
	0x0B,0x7B,0x44,0x44,0x78,0x00,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB7,0xB8,0x00,0x8F,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x8B,0x7B,	0x7B,0x7B,0x88,0x88,0x88,0x00,0x48,0xB7,
	0xB7,0xB8,0x00,0x00,0x00,0x00,0x44,0x88,	0x88,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,
	0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x01,	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,
	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,	0x00,0x00,0x00,0x03,0x00,0x00,0x00,0xFF,
	0x00,0x00,0x01,0xFF,0x00,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0x00,0x00,0x28,0x00,
	0x00,0x00,0x20,0x00,0x00,0x00,0x40,0x00,	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,
	0x00,0x00,0x80,0x02,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,
	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,
	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,
	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,
	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x83,0x33,	0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,
	0x33,0x33,0x33,0x33,0x33,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,
	0xB7,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,
	0x7B,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB8,0x88,0x88,0x88,0x88,
	0x88,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x00,0x00,0x00,0x00,0x00,
	0x08,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0x0F,0xFF,0xFF,0xFF,0xFF,
	0x08,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x0F,0x0F,0x0F,0x0F,0x0F,
	0x08,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0x0F,0xFF,0xFF,0xFF,0xFF,
	0x08,0x88,0x88,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x0F,0x0F,0x00,0x00,0x00,
	0x00,0x00,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0x0F,0xFF,0x0F,0xFF,0xFF,
	0x0F,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x0F,0x0F,0x0F,0x0F,0x0F,
	0x0F,0x0F,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB0,0x00,0x0F,0xFF,0x0F,0xFF,0xFF,
	0x0F,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x70,0xBB,0x44,0x44,0x44,0x44,0x44,
	0x4F,0x0F,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0x00,0x07,0x44,0x44,0x44,0x44,0x44,
	0x4F,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x00,0x0B,0x7B,0x7B,0x0F,0x0F,0x0F,
	0x0F,0x0F,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB0,0x00,0x00,0xB7,0xB7,0x0F,0xFF,0xFF,
	0xFF,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x3B,0x3B,0x7B,0x7B,0x44,0x44,0x44,
	0x44,0x44,0x48,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0x37,0x37,0xB7,0xB7,0x44,0x44,0x44,
	0x44,0x44,0x47,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,
	0x7B,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,
	0xB7,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0x30,0x87,0x77,	0x77,0x77,0x77,0x77,0x77,0x77,0x88,0x88,
	0x88,0x88,0x88,0x88,0x88,0x00,0x48,0xFB,	0x7B,0x7B,0x7B,0x7B,0x7B,0x78,0xF4,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0x8F,	0xB7,0xB7,0xB7,0xB7,0xB7,0x8F,0x40,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF8,	0xFF,0xFF,0xFF,0xFF,0xF8,0xF4,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0x88,0x88,0x88,0x88,0x8F,0x40,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x44,0x44,0x44,0x44,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0x80,0x00,0x00,0x01,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
	0x3F,0xFF,0x00,0x00,0x7F,0xFF,0x00,0x00,	0xFF,0xFF,0x00,0x01,0xFF,0xFF,0x00,0x03,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/icon/folder.ico.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "folder.ico"

const unsigned char _mgir_ico_folder_data[]={
	0x00,0x00,0x01,0x00,0x02,0x00,0x10,0x10,	0x10,0x00,0x00,0x00,0x00,0x00,0x28,0x01,
	0x00,0x00,0x26,0x00,0x00,0x00,0x20,0x20,	0x10,0x00,0x00,0x00,0x00,0x00,0xE8,0x02,
	0x00,0x00,0x4E,0x01,0x00,0x00,0x28,0x00,	0x00,0x00,0x10,0x00,0x00,0x00,0x20,0x00,
	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,	0x00,0x00,0xC0,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,
	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,
	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,
	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x88,
	0x88,0x88,0x88,0x88,0x88,0x00,0x8F,0xB7,	0xB0,0x00,0x07,0xB7,0xB8,0x00,0x8F,0x7B,
	0x70,0xF7,0x0B,0x7B,0x78,0x00,0x8F,0xB0,	0x00,0x7F,0x00,0x00,0xB8,0x00,0x8F,0x70,
	0x74,0x44,0x0F,0x70,0x78,0x00,0x8F,0xB0,	0xB7,0xB7,0x47,0xF0,0xB8,0x08,0x8F,0x70,
	0x0B,0x7B,0x44,0x44,0x78,0x00,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB7,0xB8,0x00,0x8F,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x8B,0x7B,	0x7B,0x7B,0x88,0x88,0x88,0x00,0x48,0xB7,
	0xB7,0xB8,0x00,0x00,0x00,0x00,0x44,0x88,	0x88,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,
	0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x01,	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,
	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,	0x00,0x00,0x00,0x03,0x00,0x00,0x00,0xFF,
	0x00,0x00,0x01,0xFF,0x00,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0x00,0x00,0x28,0x00,
	0x00,0x00,0x20,0x00,0x00,0x00,0x40,0x00,	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,
	0x00,0x00,0x80,0x02,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,
	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,
	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,
	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,
	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x83,0x33,	0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,
	0x33,0x33,0x33,0x33,0x33,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,
	0xB7,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,
	0x7B,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB8,0x88,0x88,0x88,0x88,
	0x88,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x00,0x00,0x00,0x00,0x00,
	0x08,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0x0F,0xFF,0xFF,0xFF,0xFF,
	0x08,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x0F,0x0F,0x0F,0x0F,0x0F,
	0x08,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0x0F,0xFF,0xFF,0xFF,0xFF,
	0x08,0x88,0x88,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x0F,0x0F,0x00,0x00,0x00,
	0x00,0x00,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0x0F,0xFF,0x0F,0xFF,0xFF,
	0x0F,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x0F,0x0F,0x0F,0x0F,0x0F,
	0x0F,0x0F,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB0,0x00,0x0F,0xFF,0x0F,0xFF,0xFF,
	0x0F,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x70,0xBB,0x44,0x44,0x44,0x44,0x44,
	0x4F,0x0F,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0x00,0x07,0x44,0x44,0x44,0x44,0x44,
	0x4F,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x00,0x0B,0x7B,0x7B,0x0F,0x0F,0x0F,
	0x0F,0x0F,0x08,0x7B,0x7B,0x30,0x8F,0xB7,	0xB0,0x00,0x00,0xB7,0xB7,0x0F,0xFF,0xFF,
	0xFF,0xFF,0x08,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x3B,0x3B,0x7B,0x7B,0x44,0x44,0x44,
	0x44,0x44,0x48,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0x37,0x37,0xB7,0xB7,0x44,0x44,0x44,
	0x44,0x44,0x47,0xB7,0xB7,0x30,0x8F,0x7B,	0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,0x7B,
	0x7B,0x7B,0x7B,0x7B,0x7B,0x30,0x8F,0xB7,	0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,0xB7,
	0xB7,0xB7,0xB7,0xB7,0xB7,0x30,0x8F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0x30,0x87,0x77,	0x77,0x77,0x77,0x77,0x77,0x77,0x88,0x88,
	0x88,0x88,0x88,0x88,0x88,0x00,0x48,0xFB,	0x7B,0x7B,0x7B,0x7B,0x7B,0x78,0xF4,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0x8F,	0xB7,0xB7,0xB7,0xB7,0xB7,0x8F,0x40,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF8,	0xFF,0xFF,0xFF,0xFF,0xF8,0xF4,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0x88,0x88,0x88,0x88,0x8F,0x40,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x44,0x44,0x44,0x44,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0x80,0x00,0x00,0x01,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
	0x3F,0xFF,0x00,0x00,0x7F,0xFF,0x00,0x00,	0xFF,0xFF,0x00,0x01,0xFF,0xFF,0x00,0x03,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF
};
#endif //_MGINCORE_RES
